<?php /* Smarty version 2.6.20, created on 2008-12-29 17:59:02
         compiled from header.tpl */ ?>
<div id="header">


<div id=kensaku>
<form action="book_search.php" method="GET">
		<p>
		
		<span class="small_font"> 本のタイトルを入力してください </span>
			<input  type="text" name="name"   value="" />
	    	<label>
	    	<input type="submit" name="Submit" value="検索" />
	    	<input type="hidden" name="switch" value="on" />
		</label>
		</p>
		</form> 		
	</div> <div id="header_login">

<?php if ($_COOKIE['TestCookie'] == true): ?>
	<ul>
	<li><a href="userinfo.php">鈴木将之さんの情報</a></li>
	<li><a href="logout.php">ログアウト</a></li>
	</ul>
<?php else: ?>
	<ul>
	<li><a href="login.php">ログイン</a></li>
	<li><a href="entry.php">会員登録</a></li>
	</ul>
<?php endif; ?>
</div>

	<div id="header_menu">
		<ul id="header_ul">
      		      		<li><a href="index.php">TOP</a></li>
      		<li><a href="book_search.php?switch=all">一覧</a></li>
      		<li><a href="">HELP</a></li>
      		<li></li>
    	</ul>
  </div> 
</div> 
